@@ -47,6 +47,7 @@ SourceTypeType = Literal["S3"]
 locationTypeType = Literal["INGESTION", "SAGEMAKER"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -79,6 +80,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
